@@ -889,6 +889,7 @@ class Database:
                 if check_bool_dict[error] == False:
                     err_msg += error + ','
             print(err_msg)
+
     def get_ccass_by_id_change(self, ccass_id, start_date, end_date):
 
         check_bool_dict = self.check_ccass_by_id_args(ccass_id, start_date, end_date)
@@ -1018,7 +1019,7 @@ class Database:
 
         return df
     
-    def get_hk_index_const(self, index_name):
+    def get_hk_index_const(self, index_name, sort_mkt_cap = False):
         
         if len(index_name) > 0:
 
@@ -1058,6 +1059,11 @@ class Database:
                             df[col] = pd.to_datetime(df[col], format='%Y-%m-%d')
                     df = df[['code','name','start_date','end_date','is_active']]
 
+                if sort_mkt_cap:
+                    info = self.get_basic_hk_stock_info()
+                    info = info[['code','market_capital']]
+                    df = pd.merge(df, info, on='code', how='inner')
+                    df = df.sort_values(by='market_capital', ascending=False)
 
                 return df
 
@@ -1374,6 +1380,7 @@ class Database:
                     df = df.rename(columns={'year_month': 'contract_month'})
                 if 'volumne' in df.columns:
                     df = df.rename(columns={'volumne': 'volume'})
+
                 return df
 
         else:
